@@ -1,6 +1,6 @@
-use super::{CharacterString, DnsPacketContent, Name, TYPE};
+use super::{DnsPacketContent, Name, TYPE};
 use core::fmt::Debug;
-use std::collections::HashMap;
+use std::{collections::HashMap, convert::TryInto};
 
 mod a;
 mod aaaa;
@@ -10,17 +10,18 @@ mod mx;
 mod null;
 mod soa;
 mod srv;
+mod txt;
 mod wks;
 
 pub use a::A;
 pub use aaaa::AAAA;
-use byteorder::{BigEndian, ByteOrder};
 pub use hinfo::HINFO;
 pub use minfo::MINFO;
 pub use mx::MX;
 pub use null::NULL;
 pub use soa::SOA;
 pub use srv::SRV;
+pub use txt::TXT;
 pub use wks::WKS;
 
 /// Represents the RData of each [`TYPE`]
@@ -39,7 +40,7 @@ pub enum RData<'a> {
     HINFO(HINFO<'a>),
     MINFO(MINFO<'a>),
     MX(MX<'a>),
-    TXT(CharacterString<'a>),
+    TXT(TXT<'a>),
     SOA(Box<SOA<'a>>),
     WKS(WKS<'a>),
     SRV(Box<SRV<'a>>),
@@ -51,8 +52,8 @@ impl<'a> DnsPacketContent<'a> for RData<'a> {
     where
         Self: Sized,
     {
-        let rdatatype = BigEndian::read_u16(&data[position..position + 2]).into();
-        let rdatalen = BigEndian::read_u16(&data[position + 8..position + 10]) as usize;
+        let rdatatype = u16::from_be_bytes(data[position..position + 2].try_into()?).into();
+        let rdatalen = u16::from_be_bytes(data[position + 8..position + 10].try_into()?) as usize;
 
         parse_rdata(&data[position + 10..position + 10 + rdatalen], 0, rdatatype)
     }
@@ -174,7 +175,7 @@ fn parse_rdata(data: &[u8], position: usize, rdatatype: TYPE) -> crate::Result<R
         TYPE::HINFO => RData::HINFO(HINFO::parse(data, position)?),
         TYPE::MINFO => RData::MINFO(MINFO::parse(data, position)?),
         TYPE::MX => RData::MX(MX::parse(data, position)?),
-        TYPE::TXT => RData::TXT(CharacterString::parse(data, position)?),
+        TYPE::TXT => RData::TXT(TXT::parse(data, position)?),
         TYPE::SRV => RData::SRV(Box::new(SRV::parse(data, position)?)),
         rdatatype => RData::NULL(rdatatype.into(), NULL::parse(data, position)?),
     };
